@@ -27,10 +27,10 @@ impl Command for ColumnsDF {
         vec![Example {
             description: "Dataframe columns",
             example: "[[a b]; [1 2] [3 4]] | dfr into-df | dfr columns",
-            result: Some(Value::List {
-                vals: vec![Value::test_string("a"), Value::test_string("b")],
-                span: Span::test_data(),
-            }),
+            result: Some(Value::list(
+                vec![Value::test_string("a"), Value::test_string("b")],
+                Span::test_data(),
+            )),
         }]
     }
 
@@ -60,10 +60,7 @@ fn command(
         .map(|v| Value::string(*v, call.head))
         .collect();
 
-    let names = Value::List {
-        vals: names,
-        span: call.head,
-    };
+    let names = Value::list(names, call.head);
 
     Ok(PipelineData::Value(names, None))
 }
