@@ -61,7 +61,7 @@ impl Command for ArgSort {
             },
             Example {
                 description: "Returns indexes for a sorted series",
-                example: "[1 2 2 3 3] | dfr into-df | dfr arg-sort -r",
+                example: "[1 2 2 3 3] | dfr into-df | dfr arg-sort --reverse",
                 result: Some(
                     NuDataFrame::try_from_columns(vec![Column::new(
                         "arg_sort".to_string(),
