@@ -2,8 +2,8 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span, SyntaxShape,
-    Type, Value,
+    Category, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span,
+    SyntaxShape, Type, Value,
 };
 
 use super::{vertical_rotate_value, VerticalDirection};
@@ -37,26 +37,23 @@ impl Command for RollDown {
         vec![Example {
             description: "Rolls rows down of a table",
             example: "[[a b]; [1 2] [3 4] [5 6]] | roll down",
-            result: Some(Value::List {
-                vals: vec![
-                    Value::Record {
+            result: Some(Value::list(
+                vec![
+                    Value::test_record(Record {
                         cols: columns.clone(),
                         vals: vec![Value::test_int(5), Value::test_int(6)],
-                        span: Span::test_data(),
-                    },
-                    Value::Record {
+                    }),
+                    Value::test_record(Record {
                         cols: columns.clone(),
                         vals: vec![Value::test_int(1), Value::test_int(2)],
-                        span: Span::test_data(),
-                    },
-                    Value::Record {
+                    }),
+                    Value::test_record(Record {
                         cols: columns,
                         vals: vec![Value::test_int(3), Value::test_int(4)],
-                        span: Span::test_data(),
-                    },
+                    }),
                 ],
-                span: Span::test_data(),
-            }),
+                Span::test_data(),
+            )),
         }]
     }
 
