@@ -247,6 +247,24 @@ pub fn lookup_style(s: &str) -> Style {
         "lpbl" | "light_purple_blink" => Color::LightPurple.blink(),
         "lpst" | "light_purple_strike" => Color::LightPurple.strikethrough(),
 
+        "m" | "magenta" => Color::Magenta.normal(),
+        "mb" | "magenta_bold" => Color::Magenta.bold(),
+        "mu" | "magenta_underline" => Color::Magenta.underline(),
+        "mi" | "magenta_italic" => Color::Magenta.italic(),
+        "md" | "magenta_dimmed" => Color::Magenta.dimmed(),
+        "mr" | "magenta_reverse" => Color::Magenta.reverse(),
+        "mbl" | "magenta_blink" => Color::Magenta.blink(),
+        "mst" | "magenta_strike" => Color::Magenta.strikethrough(),
+
+        "lm" | "light_magenta" => Color::LightMagenta.normal(),
+        "lmb" | "light_magenta_bold" => Color::LightMagenta.bold(),
+        "lmu" | "light_magenta_underline" => Color::LightMagenta.underline(),
+        "lmi" | "light_magenta_italic" => Color::LightMagenta.italic(),
+        "lmd" | "light_magenta_dimmed" => Color::LightMagenta.dimmed(),
+        "lmr" | "light_magenta_reverse" => Color::LightMagenta.reverse(),
+        "lmbl" | "light_magenta_blink" => Color::LightMagenta.blink(),
+        "lmst" | "light_magenta_strike" => Color::LightMagenta.strikethrough(),
+
         "c" | "cyan" => Color::Cyan.normal(),
         "cb" | "cyan_bold" => Color::Cyan.bold(),
         "cu" | "cyan_underline" => Color::Cyan.underline(),
