@@ -2,22 +2,22 @@ mod binary;
 mod bool;
 mod command;
 mod datetime;
-mod decimal;
 mod duration;
 mod filesize;
 mod float;
 mod int;
 mod record;
 mod string;
+mod value;
 
 pub use self::bool::SubCommand as IntoBool;
 pub use self::filesize::SubCommand as IntoFilesize;
 pub use binary::SubCommand as IntoBinary;
 pub use command::Into;
 pub use datetime::SubCommand as IntoDatetime;
-pub use decimal::SubCommand as IntoDecimal;
 pub use duration::SubCommand as IntoDuration;
 pub use float::SubCommand as IntoFloat;
 pub use int::SubCommand as IntoInt;
 pub use record::SubCommand as IntoRecord;
 pub use string::SubCommand as IntoString;
+pub use value::IntoValue;
