@@ -71,10 +71,7 @@ impl Command for SubCommand {
             .expect("to timezone: help example is invalid")
             .with_ymd_and_hms(2020, 10, 10, 13, 00, 00)
         {
-            LocalResult::Single(dt) => Some(Value::Date {
-                val: dt,
-                span: Span::test_data(),
-            }),
+            LocalResult::Single(dt) => Some(Value::date(dt, Span::test_data())),
             _ => panic!("to timezone: help example is invalid"),
         };
 
@@ -109,12 +106,10 @@ impl Command for SubCommand {
 }
 
 fn helper(value: Value, head: Span, timezone: &Spanned<String>) -> Value {
+    let val_span = value.span();
     match value {
-        Value::Date { val, span: _ } => _to_timezone(val, timezone, head),
-        Value::String {
-            val,
-            span: val_span,
-        } => {
+        Value::Date { val, .. } => _to_timezone(val, timezone, head),
+        Value::String { val, .. } => {
             let time = parse_date_from_string(&val, val_span);
             match time {
                 Ok(dt) => _to_timezone(dt, timezone, head),
@@ -122,25 +117,27 @@ fn helper(value: Value, head: Span, timezone: &Spanned<String>) -> Value {
             }
         }
 
-        Value::Nothing { span: _ } => {
+        Value::Nothing { .. } => {
             let dt = Local::now();
             _to_timezone(dt.with_timezone(dt.offset()), timezone, head)
         }
-        _ => Value::Error {
-            error: Box::new(ShellError::DatetimeParseError(value.debug_value(), head)),
-        },
+        _ => Value::error(
+            ShellError::DatetimeParseError(value.debug_value(), head),
+            head,
+        ),
     }
 }
 
 fn _to_timezone(dt: DateTime<FixedOffset>, timezone: &Spanned<String>, span: Span) -> Value {
     match datetime_in_timezone(&dt, timezone.item.as_str()) {
-        Ok(dt) => Value::Date { val: dt, span },
-        Err(_) => Value::Error {
-            error: Box::new(ShellError::TypeMismatch {
+        Ok(dt) => Value::date(dt, span),
+        Err(_) => Value::error(
+            ShellError::TypeMismatch {
                 err_message: String::from("invalid time zone"),
                 span: timezone.span,
-            }),
-        },
+            },
+            timezone.span,
+        ),
     }
 }
 
