@@ -1,7 +1,7 @@
 use nu_protocol::engine::{EngineState, StateWorkingSet};
 
 use crate::{
-    help::{HelpAliases, HelpCommands, HelpExterns, HelpModules, HelpOperators},
+    help::{HelpAliases, HelpCommands, HelpEscapes, HelpExterns, HelpModules, HelpOperators},
     *,
 };
 pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
@@ -127,12 +127,14 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             HelpCommands,
             HelpModules,
             HelpOperators,
+            HelpEscapes,
         };
 
         // Debug
         bind_command! {
             Ast,
             Debug,
+            DebugInfo,
             Explain,
             Inspect,
             Metadata,
@@ -286,13 +288,13 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             IntoBool,
             IntoBinary,
             IntoDatetime,
-            IntoDecimal,
             IntoDuration,
             IntoFloat,
             IntoFilesize,
             IntoInt,
             IntoRecord,
             IntoString,
+            IntoValue,
         };
 
         // Env
@@ -355,6 +357,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             HttpOptions,
             Url,
             UrlBuildQuery,
+            UrlDecode,
             UrlEncode,
             UrlJoin,
             UrlParse,
@@ -366,9 +369,9 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             Random,
             RandomBool,
             RandomChars,
-            RandomDecimal,
             RandomDice,
             RandomFloat,
+            RandomInt,
             RandomInteger,
             RandomUuid,
         };
@@ -379,6 +382,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             Seq,
             SeqDate,
             SeqChar,
+            Unfold,
         };
 
         // Hash
