@@ -276,7 +276,10 @@ fn move_file(
     };
 
     if !destination_dir_exists {
-        return Err(ShellError::DirectoryNotFound(to_span, None));
+        return Err(ShellError::DirectoryNotFound(
+            to_span,
+            to.to_string_lossy().to_string(),
+        ));
     }
 
     // This can happen when changing case on a case-insensitive filesystem (ex: changing foo to Foo on Windows)
@@ -287,7 +290,12 @@ fn move_file(
     if !from_to_are_same_file && to.is_dir() {
         let from_file_name = match from.file_name() {
             Some(name) => name,
-            None => return Err(ShellError::DirectoryNotFound(to_span, None)),
+            None => {
+                return Err(ShellError::DirectoryNotFound(
+                    to_span,
+                    from.to_string_lossy().to_string(),
+                ))
+            }
         };
 
         to.push(from_file_name);
