@@ -52,7 +52,7 @@ impl Command for Default {
             Example {
                 description:
                     "Get the env value of `MY_ENV` with a default value 'abc' if not present",
-                example: "$env | get -i MY_ENV | default 'abc'",
+                example: "$env | get --ignore-errors MY_ENV | default 'abc'",
                 result: None, // Some(Value::test_string("abc")),
             },
             Example {
