@@ -1,4 +1,3 @@
-use super::utils::chain_error_with_input;
 use nu_engine::{eval_block_with_early_return, CallExt};
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Closure, Command, EngineState, Stack};
@@ -7,6 +6,8 @@ use nu_protocol::{
     SyntaxShape, Type, Value,
 };
 
+use super::utils::chain_error_with_input;
+
 #[derive(Clone)]
 pub struct Items;
 
@@ -85,18 +86,15 @@ impl Command for Items {
                 Ok(v) => Some(v.into_value(span)),
                 Err(ShellError::Break(_)) => None,
                 Err(error) => {
-                    let error = chain_error_with_input(error, Ok(input_span));
-                    Some(Value::Error {
-                        error: Box::new(error),
-                    })
+                    let error = chain_error_with_input(error, false, input_span);
+                    Some(Value::error(error, span))
                 }
             }
         };
         match input {
             PipelineData::Empty => Ok(PipelineData::Empty),
-            PipelineData::Value(Value::Record { cols, vals, .. }, ..) => Ok(cols
+            PipelineData::Value(Value::Record { val, .. }, ..) => Ok(val
                 .into_iter()
-                .zip(vals)
                 .map_while(run_for_each_item)
                 .into_pipeline_data(ctrlc)),
             // Errors
@@ -106,12 +104,12 @@ impl Command for Items {
                 dst_span: call.head,
                 src_span: input_span,
             }),
-            PipelineData::Value(Value::Error { error }, ..) => Err(*error),
+            PipelineData::Value(Value::Error { error, .. }, ..) => Err(*error),
             PipelineData::Value(other, ..) => Err(ShellError::OnlySupportsThisInputType {
                 exp_input_type: "record".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: call.head,
-                src_span: other.expect_span(),
+                src_span: other.span(),
             }),
             PipelineData::ExternalStream { .. } => Err(ShellError::OnlySupportsThisInputType {
                 exp_input_type: "record".into(),
@@ -128,13 +126,13 @@ impl Command for Items {
             example:
                 "{ new: york, san: francisco } | items {|key, value| echo $'($key) ($value)' }",
             description: "Iterate over each key-value pair of a record",
-            result: Some(Value::List {
-                vals: vec![
+            result: Some(Value::list(
+                vec![
                     Value::test_string("new york"),
                     Value::test_string("san francisco"),
                 ],
-                span: Span::test_data(),
-            }),
+                Span::test_data(),
+            )),
         }]
     }
 }
