@@ -2,8 +2,8 @@ use nu_engine::{eval_block, CallExt};
 use nu_protocol::{
     ast::Call,
     engine::{Closure, Command, EngineState, Stack},
-    Category, Example, IntoInterruptiblePipelineData, PipelineData, ShellError, Signature, Span,
-    SyntaxShape, Type, Value,
+    Category, Example, IntoInterruptiblePipelineData, PipelineData, Record, ShellError, Signature,
+    Span, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -40,29 +40,35 @@ impl Command for TakeWhile {
             Example {
                 description: "Take while the element is negative",
                 example: "[-1 -2 9 1] | take while {|x| $x < 0 }",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(-1), Value::test_int(-2)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(-1), Value::test_int(-2)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Take while the element is negative using stored condition",
                 example: "let cond = {|x| $x < 0 }; [-1 -2 9 1] | take while $cond",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(-1), Value::test_int(-2)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(-1), Value::test_int(-2)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Take while the field value is negative",
                 example: "[{a: -1} {a: -2} {a: 9} {a: 1}] | take while {|x| $x.a < 0 }",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::test_record(vec!["a"], vec![Value::test_int(-1)]),
-                        Value::test_record(vec!["a"], vec![Value::test_int(-2)]),
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
+                            cols: vec!["a".to_string()],
+                            vals: vec![Value::test_int(-1)],
+                        }),
+                        Value::test_record(Record {
+                            cols: vec!["a".to_string()],
+                            vals: vec![Value::test_int(-2)],
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
         ]
     }
