@@ -3,7 +3,7 @@ use nu_protocol::ast::{Call, CellPath, PathMember};
 use nu_protocol::engine::{Closure, Command, EngineState, Stack};
 use nu_protocol::{
     Category, Example, FromValue, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData,
-    ShellError, Signature, Span, SyntaxShape, Type, Value,
+    Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -57,33 +57,43 @@ impl Command for Update {
             Example {
                 description: "Update a column value",
                 example: "{'name': 'nu', 'stars': 5} | update name 'Nushell'",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["name".into(), "stars".into()],
                     vals: vec![Value::test_string("Nushell"), Value::test_int(5)],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             Example {
                 description: "Use in closure form for more involved updating logic",
                 example: "[[count fruit]; [1 'apple']] | enumerate | update item.count {|e| ($e.item.fruit | str length) + $e.index } | get item",
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
                         cols: vec!["count".into(), "fruit".into()],
                         vals: vec![Value::test_int(5), Value::test_string("apple")],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Alter each value in the 'authors' column to use a single string instead of a list",
                 example: "[[project, authors]; ['nu', ['Andrés', 'JT', 'Yehuda']]] | update authors {|row| $row.authors | str join ','}",
-                result: Some(Value::List { vals: vec![Value::Record { cols: vec!["project".into(), "authors".into()], vals: vec![Value::test_string("nu"), Value::test_string("Andrés,JT,Yehuda")], span: Span::test_data()}], span: Span::test_data()}),
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
+                        cols: vec!["project".into(), "authors".into()],
+                        vals: vec![Value::test_string("nu"), Value::test_string("Andrés,JT,Yehuda")],
+                    })],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "You can also use a simple command to update 'authors' to a single string",
                 example: "[[project, authors]; ['nu', ['Andrés', 'JT', 'Yehuda']]] | update authors {|| str join ','}",
-                result: Some(Value::List { vals: vec![Value::Record { cols: vec!["project".into(), "authors".into()], vals: vec![Value::test_string("nu"), Value::test_string("Andrés,JT,Yehuda")], span: Span::test_data()}], span: Span::test_data()}),
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
+                        cols: vec!["project".into(), "authors".into()],
+                        vals: vec![Value::test_string("nu"), Value::test_string("Andrés,JT,Yehuda")],
+                    })],
+                    Span::test_data(),
+                )),
             }
         ]
     }
@@ -106,6 +116,10 @@ fn update(
     let engine_state = engine_state.clone();
     let ctrlc = engine_state.ctrlc.clone();
 
+    // Let's capture the metadata for ls_colors
+    let metadata = input.metadata();
+    let mdclone = metadata.clone();
+
     // Replace is a block, so set it up and run it instead of using it as the replacement
     if replacement.as_block().is_ok() {
         let capture_block: Closure = FromValue::from_value(&replacement)?;
@@ -115,48 +129,50 @@ fn update(
         let orig_env_vars = stack.env_vars.clone();
         let orig_env_hidden = stack.env_hidden.clone();
 
-        input.map(
-            move |mut input| {
-                // with_env() is used here to ensure that each iteration uses
-                // a different set of environment variables.
-                // Hence, a 'cd' in the first loop won't affect the next loop.
-                stack.with_env(&orig_env_vars, &orig_env_hidden);
+        Ok(input
+            .map(
+                move |mut input| {
+                    // with_env() is used here to ensure that each iteration uses
+                    // a different set of environment variables.
+                    // Hence, a 'cd' in the first loop won't affect the next loop.
+                    stack.with_env(&orig_env_vars, &orig_env_hidden);
 
-                if let Some(var) = block.signature.get_positional(0) {
-                    if let Some(var_id) = &var.var_id {
-                        stack.add_var(*var_id, input.clone())
-                    }
-                }
-
-                let input_at_path = match input.clone().follow_cell_path(&cell_path.members, false)
-                {
-                    Err(e) => return Value::Error { error: Box::new(e) },
-                    Ok(v) => v,
-                };
-                let output = eval_block(
-                    &engine_state,
-                    &mut stack,
-                    &block,
-                    input_at_path.into_pipeline_data(),
-                    redirect_stdout,
-                    redirect_stderr,
-                );
-
-                match output {
-                    Ok(pd) => {
-                        if let Err(e) =
-                            input.update_data_at_cell_path(&cell_path.members, pd.into_value(span))
-                        {
-                            return Value::Error { error: Box::new(e) };
+                    if let Some(var) = block.signature.get_positional(0) {
+                        if let Some(var_id) = &var.var_id {
+                            stack.add_var(*var_id, input.clone())
                         }
-
-                        input
                     }
-                    Err(e) => Value::Error { error: Box::new(e) },
-                }
-            },
-            ctrlc,
-        )
+
+                    let input_at_path =
+                        match input.clone().follow_cell_path(&cell_path.members, false) {
+                            Err(e) => return Value::error(e, span),
+                            Ok(v) => v,
+                        };
+                    let output = eval_block(
+                        &engine_state,
+                        &mut stack,
+                        &block,
+                        input_at_path.into_pipeline_data_with_metadata(metadata.clone()),
+                        redirect_stdout,
+                        redirect_stderr,
+                    );
+
+                    match output {
+                        Ok(pd) => {
+                            if let Err(e) = input
+                                .update_data_at_cell_path(&cell_path.members, pd.into_value(span))
+                            {
+                                return Value::error(e, span);
+                            }
+
+                            input
+                        }
+                        Err(e) => Value::error(e, span),
+                    }
+                },
+                ctrlc,
+            )?
+            .set_metadata(mdclone))
     } else {
         if let Some(PathMember::Int { val, span, .. }) = cell_path.members.get(0) {
             let mut input = input.into_iter();
@@ -182,20 +198,23 @@ fn update(
                 .into_iter()
                 .chain(vec![replacement])
                 .chain(input)
-                .into_pipeline_data(ctrlc));
+                .into_pipeline_data_with_metadata(metadata, ctrlc));
         }
-        input.map(
-            move |mut input| {
-                let replacement = replacement.clone();
+        Ok(input
+            .map(
+                move |mut input| {
+                    let replacement = replacement.clone();
 
-                if let Err(e) = input.update_data_at_cell_path(&cell_path.members, replacement) {
-                    return Value::Error { error: Box::new(e) };
-                }
+                    if let Err(e) = input.update_data_at_cell_path(&cell_path.members, replacement)
+                    {
+                        return Value::error(e, span);
+                    }
 
-                input
-            },
-            ctrlc,
-        )
+                    input
+                },
+                ctrlc,
+            )?
+            .set_metadata(metadata))
     }
 }
 
