@@ -4,7 +4,7 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    Category, Example, PipelineData, Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -21,7 +21,7 @@ impl Command for FromCsv {
             .named(
                 "separator",
                 SyntaxShape::String,
-                "a character to separate columns, defaults to ','",
+                "a character to separate columns (either single char or 4 byte unicode sequence), defaults to ','",
                 Some('s'),
             )
             .named(
@@ -81,17 +81,16 @@ impl Command for FromCsv {
             Example {
                 description: "Convert comma-separated data to a table",
                 example: "\"ColA,ColB\n1,2\" | from csv",
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list (
+                    vec![Value::test_record(Record {
                         cols: vec!["ColA".to_string(), "ColB".to_string()],
                         vals: vec![
                             Value::test_int(1),
                             Value::test_int(2),
                         ],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                })
+                    })],
+                    Span::test_data(),
+                ))
             },
             Example {
                 description: "Convert comma-separated data to a table, ignoring headers",
@@ -135,11 +134,22 @@ fn from_csv(
 ) -> Result<PipelineData, ShellError> {
     let name = call.head;
 
-    let separator = call
-        .get_flag(engine_state, stack, "separator")?
-        .map(|v: Value| v.as_char())
-        .transpose()?
-        .unwrap_or(',');
+    let separator = match call.get_flag::<String>(engine_state, stack, "separator")? {
+        Some(sep) => {
+            if sep.len() == 1 {
+                sep.chars().next().unwrap_or(',')
+            } else if sep.len() == 4 {
+                let unicode_sep = u32::from_str_radix(&sep, 16);
+                char::from_u32(unicode_sep.unwrap_or(b'\x1f' as u32)).unwrap_or(',')
+            } else {
+                return Err(ShellError::NonUtf8Custom(
+                    "separator should be a single char or a 4-byte unicode".to_string(),
+                    call.span(),
+                ));
+            }
+        }
+        None => ',',
+    };
     let comment = call
         .get_flag(engine_state, stack, "comment")?
         .map(|v: Value| v.as_char())
