@@ -1,8 +1,8 @@
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData, ShellError,
-    Signature, Span, Type, Value,
+    Category, Example, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData, Record,
+    ShellError, Signature, Span, Type, Value,
 };
 
 #[derive(Clone)]
@@ -29,26 +29,24 @@ impl Command for FromJson {
             Example {
                 example: r#"'{ "a": 1 }' | from json"#,
                 description: "Converts json formatted string to table",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["a".to_string()],
                     vals: vec![Value::test_int(1)],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             Example {
                 example: r#"'{ "a": 1, "b": [1, 2] }' | from json"#,
                 description: "Converts json formatted string to table",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["a".to_string(), "b".to_string()],
                     vals: vec![
                         Value::test_int(1),
-                        Value::List {
-                            vals: vec![Value::test_int(1), Value::test_int(2)],
-                            span: Span::test_data(),
-                        },
+                        Value::list(
+                            vec![Value::test_int(1), Value::test_int(2)],
+                            Span::test_data(),
+                        ),
                     ],
-                    span: Span::test_data(),
-                }),
+                })),
             },
         ]
     }
@@ -77,9 +75,7 @@ impl Command for FromJson {
                     } else {
                         match convert_string_to_value(x.to_string(), span) {
                             Ok(v) => Some(v),
-                            Err(error) => Some(Value::Error {
-                                error: Box::new(error),
-                            }),
+                            Err(error) => Some(Value::error(error, span)),
                         }
                     }
                 })
@@ -101,44 +97,34 @@ fn convert_nujson_to_value(value: &nu_json::Value, span: Span) -> Value {
                 .map(|x| convert_nujson_to_value(x, span))
                 .collect();
 
-            Value::List { vals: v, span }
-        }
-        nu_json::Value::Bool(b) => Value::Bool { val: *b, span },
-        nu_json::Value::F64(f) => Value::Float { val: *f, span },
-        nu_json::Value::I64(i) => Value::Int { val: *i, span },
-        nu_json::Value::Null => Value::Nothing { span },
-        nu_json::Value::Object(k) => {
-            let mut cols = vec![];
-            let mut vals = vec![];
-
-            for item in k {
-                cols.push(item.0.clone());
-                vals.push(convert_nujson_to_value(item.1, span));
-            }
-
-            Value::Record { cols, vals, span }
+            Value::list(v, span)
         }
+        nu_json::Value::Bool(b) => Value::bool(*b, span),
+        nu_json::Value::F64(f) => Value::float(*f, span),
+        nu_json::Value::I64(i) => Value::int(*i, span),
+        nu_json::Value::Null => Value::nothing(span),
+        nu_json::Value::Object(k) => Value::record(
+            k.iter()
+                .map(|(k, v)| (k.clone(), convert_nujson_to_value(v, span)))
+                .collect(),
+            span,
+        ),
         nu_json::Value::U64(u) => {
             if *u > i64::MAX as u64 {
-                Value::Error {
-                    error: Box::new(ShellError::CantConvert {
+                Value::error(
+                    ShellError::CantConvert {
                         to_type: "i64 sized integer".into(),
                         from_type: "value larger than i64".into(),
                         span,
                         help: None,
-                    }),
-                }
-            } else {
-                Value::Int {
-                    val: *u as i64,
+                    },
                     span,
-                }
+                )
+            } else {
+                Value::int(*u as i64, span)
             }
         }
-        nu_json::Value::String(s) => Value::String {
-            val: s.clone(),
-            span,
-        },
+        nu_json::Value::String(s) => Value::string(s.clone(), span),
     }
 }
 
