@@ -53,7 +53,7 @@ impl Command for FromSsv {
             )),
         }, Example {
             example: r#"'FOO   BAR
-1   2' | from ssv -n"#,
+1   2' | from ssv --noheaders"#,
             description: "Converts ssv formatted string to table but not treating the first row as column names",
             result: Some(
                 Value::list(
