@@ -93,7 +93,7 @@ impl Command for FromTsv {
             },
             Example {
                 description: "Create a tsv file without header columns and open it",
-                example: r#"$'a1(char tab)b1(char tab)c1(char nl)a2(char tab)b2(char tab)c2' | save tsv-data | open tsv-data | from tsv -n"#,
+                example: r#"$'a1(char tab)b1(char tab)c1(char nl)a2(char tab)b2(char tab)c2' | save tsv-data | open tsv-data | from tsv --noheaders"#,
                 result: None,
             },
             Example {
