@@ -148,34 +148,36 @@ pub fn highlight_search_in_table(
     let mut matches = vec![];
 
     for record in table {
-        let (cols, mut vals, record_span) = if let Value::Record { cols, vals, span } = record {
-            (cols, vals, span)
+        let span = record.span();
+        let (mut record, record_span) = if let Value::Record { val, .. } = record {
+            (val, span)
         } else {
             return Err(ShellError::NushellFailedSpanned {
                 msg: "Expected record".to_string(),
                 label: format!("got {}", record.get_type()),
-                span: record.span()?,
+                span: record.span(),
             });
         };
 
-        let has_match = cols.iter().zip(vals.iter_mut()).try_fold(
+        let has_match = record.iter_mut().try_fold(
             false,
             |acc: bool, (col, val)| -> Result<bool, ShellError> {
                 if !searched_cols.contains(&col.as_str()) {
                     // don't search this column
                     return Ok(acc);
                 }
-                if let Value::String { val: s, span } = val {
+                let span = val.span();
+                if let Value::String { val: s, .. } = val {
                     if s.to_lowercase().contains(&search_string) {
-                        *val = Value::String {
-                            val: highlight_search_string(
+                        *val = Value::string(
+                            highlight_search_string(
                                 s,
                                 orig_search_string,
                                 string_style,
                                 highlight_style,
                             )?,
-                            span: *span,
-                        };
+                            span,
+                        );
                         return Ok(true);
                     }
                 }
@@ -186,11 +188,7 @@ pub fn highlight_search_in_table(
         )?;
 
         if has_match {
-            matches.push(Value::Record {
-                cols,
-                vals,
-                span: record_span,
-            });
+            matches.push(Value::record(record, record_span));
         }
     }
 
