@@ -4,7 +4,9 @@ use crate::math::avg::average;
 use crate::math::utils::run_with_function;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
-use nu_protocol::{Category, Example, PipelineData, ShellError, Signature, Span, Type, Value};
+use nu_protocol::{
+    Category, Example, PipelineData, Record, ShellError, Signature, Span, Type, Value,
+};
 
 #[derive(Clone)]
 pub struct SubCommand;
@@ -54,11 +56,10 @@ impl Command for SubCommand {
             Example {
                 description: "Compute the medians of the columns of a table",
                 example: "[{a: 1 b: 3} {a: 2 b: -1} {a: -3 b: 5}] | math median",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["a".to_string(), "b".to_string()],
                     vals: vec![Value::test_int(1), Value::test_int(3)],
-                    span: Span::test_data(),
-                }),
+                })),
             },
         ]
     }
@@ -89,9 +90,9 @@ pub fn median(values: &[Value], span: Span, head: Span) -> Result<Value, ShellEr
                 return Err(ShellError::OperatorMismatch {
                     op_span: head,
                     lhs_ty: elem[0].get_type().to_string(),
-                    lhs_span: elem[0].span()?,
+                    lhs_span: elem[0].span(),
                     rhs_ty: elem[1].get_type().to_string(),
-                    rhs_span: elem[1].span()?,
+                    rhs_span: elem[1].span(),
                 });
             }
             Ok(elem[0].partial_cmp(&elem[1]).unwrap_or(Ordering::Equal))
