@@ -42,9 +42,9 @@ pub fn max(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellError
             return Err(ShellError::OperatorMismatch {
                 op_span: head,
                 lhs_ty: biggest.get_type().to_string(),
-                lhs_span: biggest.span()?,
+                lhs_span: biggest.span(),
                 rhs_ty: value.get_type().to_string(),
-                rhs_span: value.span()?,
+                rhs_span: value.span(),
             });
         }
     }
@@ -73,9 +73,9 @@ pub fn min(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellError
             return Err(ShellError::OperatorMismatch {
                 op_span: head,
                 lhs_ty: smallest.get_type().to_string(),
-                lhs_span: smallest.span()?,
+                lhs_span: smallest.span(),
                 rhs_ty: value.get_type().to_string(),
-                rhs_span: value.span()?,
+                rhs_span: value.span(),
             });
         }
     }
@@ -86,22 +86,22 @@ pub fn sum(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellError
     let initial_value = data.get(0);
 
     let mut acc = match initial_value {
-        Some(Value::Filesize { span, .. }) => Ok(Value::Filesize {
-            val: 0,
-            span: *span,
-        }),
-        Some(Value::Duration { span, .. }) => Ok(Value::Duration {
-            val: 0,
-            span: *span,
-        }),
-        Some(Value::Int { span, .. }) | Some(Value::Float { span, .. }) => Ok(Value::int(0, *span)),
+        Some(v) => {
+            let span = v.span();
+            match v {
+                Value::Filesize { .. } => Ok(Value::filesize(0, span)),
+                Value::Duration { .. } => Ok(Value::duration(0, span)),
+                Value::Int { .. } | Value::Float { .. } => Ok(Value::int(0, span)),
+                _ => Ok(Value::nothing(head)),
+            }
+        }
+
         None => Err(ShellError::UnsupportedInput(
             "Empty input".to_string(),
             "value originates from here".into(),
             head,
             span,
         )),
-        _ => Ok(Value::nothing(head)),
     }?;
 
     for value in &data {
@@ -112,13 +112,13 @@ pub fn sum(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellError
             | Value::Duration { .. } => {
                 acc = acc.add(head, value, head)?;
             }
-            Value::Error { error } => return Err(*error.clone()),
+            Value::Error { error, .. } => return Err(*error.clone()),
             other => {
                 return Err(ShellError::UnsupportedInput(
                     "Attempted to compute the sum of a value that cannot be summed".to_string(),
                     "value originates from here".into(),
                     head,
-                    other.expect_span(),
+                    other.span(),
                 ));
             }
         }
@@ -130,14 +130,19 @@ pub fn product(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellE
     let initial_value = data.get(0);
 
     let mut acc = match initial_value {
-        Some(Value::Int { span, .. }) | Some(Value::Float { span, .. }) => Ok(Value::int(1, *span)),
+        Some(v) => {
+            let span = v.span();
+            match v {
+                Value::Int { .. } | Value::Float { .. } => Ok(Value::int(1, span)),
+                _ => Ok(Value::nothing(head)),
+            }
+        }
         None => Err(ShellError::UnsupportedInput(
             "Empty input".to_string(),
             "value originates from here".into(),
             head,
             span,
         )),
-        _ => Ok(Value::nothing(head)),
     }?;
 
     for value in &data {
@@ -145,14 +150,14 @@ pub fn product(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellE
             Value::Int { .. } | Value::Float { .. } => {
                 acc = acc.mul(head, value, head)?;
             }
-            Value::Error { error } => return Err(*error.clone()),
+            Value::Error { error, .. } => return Err(*error.clone()),
             other => {
                 return Err(ShellError::UnsupportedInput(
                     "Attempted to compute the product of a value that cannot be multiplied"
                         .to_string(),
                     "value originates from here".into(),
                     head,
-                    other.expect_span(),
+                    other.span(),
                 ));
             }
         }
