@@ -82,7 +82,7 @@ impl Command for SubCommand {
 
     fn run(
         &self,
-        _engine_state: &EngineState,
+        engine_state: &EngineState,
         _stack: &mut Stack,
         call: &Call,
         input: PipelineData,
@@ -98,7 +98,7 @@ impl Command for SubCommand {
                         let url_components = val
                             .into_iter()
                             .try_fold(UrlComponents::new(), |url, (k, v)| {
-                                url.add_component(k, v, span)
+                                url.add_component(k, v, span, engine_state)
                             });
 
                         url_components?.to_url(span)
@@ -137,8 +137,14 @@ impl UrlComponents {
         Default::default()
     }
 
-    pub fn add_component(self, key: String, value: Value, _span: Span) -> Result<Self, ShellError> {
-        let span = value.span();
+    pub fn add_component(
+        self,
+        key: String,
+        value: Value,
+        span: Span,
+        engine_state: &EngineState,
+    ) -> Result<Self, ShellError> {
+        let value_span = value.span();
         if key == "port" {
             return match value {
                 Value::String { val, .. } => {
@@ -152,9 +158,9 @@ impl UrlComponents {
                             }),
                             Err(_) => Err(ShellError::IncompatibleParametersSingle {
                                 msg: String::from(
-                                    "Port parameter should represent an unsigned integer",
+                                    "Port parameter should represent an unsigned int",
                                 ),
-                                span,
+                                span: value_span,
                             }),
                         }
                     }
@@ -166,7 +172,7 @@ impl UrlComponents {
                 Value::Error { error, .. } => Err(*error),
                 other => Err(ShellError::IncompatibleParametersSingle {
                     msg: String::from(
-                        "Port parameter should be an unsigned integer or a string representing it",
+                        "Port parameter should be an unsigned int or a string representing it",
                     ),
                     span: other.span(),
                 }),
@@ -205,7 +211,7 @@ impl UrlComponents {
 
                     Ok(Self {
                         query: Some(qs),
-                        params_span: Some(span),
+                        params_span: Some(value_span),
                         ..self
                     })
                 }
@@ -217,69 +223,96 @@ impl UrlComponents {
             };
         }
 
-        // a part from port and params all other keys are strings.
-        match value.as_string() {
-            Ok(s) => {
-                if s.trim().is_empty() {
-                    Ok(self)
+        // apart from port and params all other keys are strings.
+        let s = value.as_string()?; // If value fails String conversion, just output this ShellError
+        if !Self::check_empty_string_ok(&key, &s, value_span)? {
+            return Ok(self);
+        }
+        match key.as_str() {
+            "host" => Ok(Self {
+                host: Some(s),
+                ..self
+            }),
+            "scheme" => Ok(Self {
+                scheme: Some(s),
+                ..self
+            }),
+            "username" => Ok(Self {
+                username: Some(s),
+                ..self
+            }),
+            "password" => Ok(Self {
+                password: Some(s),
+                ..self
+            }),
+            "path" => Ok(Self {
+                path: Some(if s.starts_with('/') {
+                    s
                 } else {
-                    match key.as_str() {
-                        "host" => Ok(Self {
-                            host: Some(s),
-                            ..self
-                        }),
-                        "scheme" => Ok(Self {
-                            scheme: Some(s),
-                            ..self
-                        }),
-                        "username" => Ok(Self {
-                            username: Some(s),
-                            ..self
-                        }),
-                        "password" => Ok(Self {
-                            password: Some(s),
-                            ..self
-                        }),
-                        "path" => Ok(Self {
-                            path: Some(if s.starts_with('/') {
-                                s
-                            } else {
-                                format!("/{s}")
-                            }),
-                            ..self
-                        }),
-                        "query" => {
-                            if let Some(q) = self.query {
-                                if q != s {
-                                    // if query is present it means that also params_span is set.
-                                    return Err(ShellError::IncompatibleParameters {
-                                        left_message: format!("Mismatch, query param is: {s}"),
-                                        left_span: value.span(),
-                                        right_message: format!("instead qs from params is: {q}"),
-                                        right_span: self.params_span.unwrap_or(Span::unknown()),
-                                    });
-                                }
-                            }
-
-                            Ok(Self {
-                                query: Some(format!("?{s}")),
-                                query_span: Some(value.span()),
-                                ..self
-                            })
-                        }
-                        "fragment" => Ok(Self {
-                            fragment: Some(if s.starts_with('#') {
-                                s
-                            } else {
-                                format!("#{s}")
-                            }),
-                            ..self
-                        }),
-                        _ => Ok(self),
+                    format!("/{s}")
+                }),
+                ..self
+            }),
+            "query" => {
+                if let Some(q) = self.query {
+                    if q != s {
+                        // if query is present it means that also params_span is set.
+                        return Err(ShellError::IncompatibleParameters {
+                            left_message: format!("Mismatch, query param is: {s}"),
+                            left_span: value.span(),
+                            right_message: format!("instead qs from params is: {q}"),
+                            right_span: self.params_span.unwrap_or(Span::unknown()),
+                        });
                     }
                 }
+
+                Ok(Self {
+                    query: Some(format!("?{s}")),
+                    query_span: Some(value.span()),
+                    ..self
+                })
             }
-            _ => Ok(self),
+            "fragment" => Ok(Self {
+                fragment: Some(if s.starts_with('#') {
+                    s
+                } else {
+                    format!("#{s}")
+                }),
+                ..self
+            }),
+            _ => {
+                nu_protocol::report_error_new(
+                    engine_state,
+                    &ShellError::GenericError(
+                        format!("'{key}' is not a valid URL field"),
+                        format!("remove '{key}' col from input record"),
+                        Some(span),
+                        None,
+                        vec![],
+                    ),
+                );
+                Ok(self)
+            }
+        }
+    }
+
+    // Check if value is empty. If so, check if that is fine, i.e., not a required input
+    fn check_empty_string_ok(key: &str, s: &str, value_span: Span) -> Result<bool, ShellError> {
+        if !s.trim().is_empty() {
+            return Ok(true);
+        }
+        match key {
+            "host" => Err(ShellError::UnsupportedConfigValue(
+                "non-empty string".into(),
+                "empty string".into(),
+                value_span,
+            )),
+            "scheme" => Err(ShellError::UnsupportedConfigValue(
+                "non-empty string".into(),
+                "empty string".into(),
+                value_span,
+            )),
+            _ => Ok(false),
         }
     }
 
