@@ -1,9 +1,9 @@
 use std::path::{Path, PathBuf};
 
-use nu_engine::current_dir;
+use nu_engine::{current_dir, current_dir_const};
 use nu_path::expand_path_with;
 use nu_protocol::ast::Call;
-use nu_protocol::engine::{EngineState, Stack};
+use nu_protocol::engine::{EngineState, Stack, StateWorkingSet};
 use nu_protocol::{
     engine::Command, Category, Example, PipelineData, ShellError, Signature, Span, Type, Value,
 };
@@ -45,6 +45,10 @@ impl Command for SubCommand {
 If you need to distinguish dirs and files, please use `path type`."#
     }
 
+    fn is_const(&self) -> bool {
+        true
+    }
+
     fn run(
         &self,
         engine_state: &EngineState,
@@ -66,6 +70,26 @@ If you need to distinguish dirs and files, please use `path type`."#
         )
     }
 
+    fn run_const(
+        &self,
+        working_set: &StateWorkingSet,
+        call: &Call,
+        input: PipelineData,
+    ) -> Result<PipelineData, ShellError> {
+        let head = call.head;
+        let args = Arguments {
+            pwd: current_dir_const(working_set)?,
+        };
+        // This doesn't match explicit nulls
+        if matches!(input, PipelineData::Empty) {
+            return Err(ShellError::PipelineEmpty { dst_span: head });
+        }
+        input.map(
+            move |value| super::operate(&exists, &args, value, head),
+            working_set.permanent().ctrlc.clone(),
+        )
+    }
+
     #[cfg(windows)]
     fn examples(&self) -> Vec<Example> {
         vec![
@@ -107,17 +131,15 @@ If you need to distinguish dirs and files, please use `path type`."#
 
 fn exists(path: &Path, span: Span, args: &Arguments) -> Value {
     let path = expand_path_with(path, &args.pwd);
-    Value::Bool {
-        val: match path.try_exists() {
+    Value::bool(
+        match path.try_exists() {
             Ok(exists) => exists,
             Err(err) => {
-                return Value::Error {
-                    error: Box::new(ShellError::IOErrorSpanned(err.to_string(), span)),
-                }
+                return Value::error(ShellError::IOErrorSpanned(err.to_string(), span), span)
             }
         },
         span,
-    }
+    )
 }
 
 #[cfg(test)]
