@@ -2,7 +2,7 @@ use std::path::Path;
 
 use nu_path::expand_tilde;
 use nu_protocol::ast::Call;
-use nu_protocol::engine::{EngineState, Stack};
+use nu_protocol::engine::{EngineState, Stack, StateWorkingSet};
 use nu_protocol::{
     engine::Command, Category, Example, PipelineData, ShellError, Signature, Span, Type, Value,
 };
@@ -43,6 +43,10 @@ impl Command for SubCommand {
 If nothing is found, an empty string will be returned."#
     }
 
+    fn is_const(&self) -> bool {
+        true
+    }
+
     fn run(
         &self,
         engine_state: &EngineState,
@@ -63,6 +67,25 @@ If nothing is found, an empty string will be returned."#
         )
     }
 
+    fn run_const(
+        &self,
+        working_set: &StateWorkingSet,
+        call: &Call,
+        input: PipelineData,
+    ) -> Result<PipelineData, ShellError> {
+        let head = call.head;
+        let args = Arguments;
+
+        // This doesn't match explicit nulls
+        if matches!(input, PipelineData::Empty) {
+            return Err(ShellError::PipelineEmpty { dst_span: head });
+        }
+        input.map(
+            move |value| super::operate(&r#type, &args, value, head),
+            working_set.permanent().ctrlc.clone(),
+        )
+    }
+
     fn examples(&self) -> Vec<Example> {
         vec![
             Example {
