@@ -1,17 +1,17 @@
 mod bool;
 mod chars;
-mod decimal;
 mod dice;
 mod float;
+mod int;
 mod integer;
 mod random_;
 mod uuid;
 
 pub use self::bool::SubCommand as RandomBool;
 pub use self::chars::SubCommand as RandomChars;
-pub use self::decimal::SubCommand as RandomDecimal;
 pub use self::dice::SubCommand as RandomDice;
 pub use self::float::SubCommand as RandomFloat;
+pub use self::int::SubCommand as RandomInt;
 pub use self::integer::SubCommand as RandomInteger;
 pub use self::uuid::SubCommand as RandomUuid;
 pub use random_::RandomCommand as Random;
