@@ -53,23 +53,23 @@ documentation link at https://docs.rs/encoding_rs/latest/encoding_rs/#statics"#
             Example {
                 description: "Encode an UTF-8 string into Shift-JIS",
                 example: r#""負けると知って戦うのが、遥かに美しいのだ" | encode shift-jis"#,
-                result: Some(Value::Binary {
-                    val: vec![
+                result: Some(Value::binary(
+                    vec![
                         0x95, 0x89, 0x82, 0xaf, 0x82, 0xe9, 0x82, 0xc6, 0x92, 0x6d, 0x82, 0xc1,
                         0x82, 0xc4, 0x90, 0xed, 0x82, 0xa4, 0x82, 0xcc, 0x82, 0xaa, 0x81, 0x41,
                         0x97, 0x79, 0x82, 0xa9, 0x82, 0xc9, 0x94, 0xfc, 0x82, 0xb5, 0x82, 0xa2,
                         0x82, 0xcc, 0x82, 0xbe,
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Replace characters with HTML entities if they can't be encoded",
                 example: r#""🎈" | encode -i shift-jis"#,
-                result: Some(Value::Binary {
-                    val: vec![0x26, 0x23, 0x31, 0x32, 0x37, 0x38, 0x38, 0x30, 0x3b],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(
+                    vec![0x26, 0x23, 0x31, 0x32, 0x37, 0x38, 0x38, 0x30, 0x3b],
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -95,19 +95,22 @@ documentation link at https://docs.rs/encoding_rs/latest/encoding_rs/#statics"#
                 super::encoding::encode(head, encoding, &s.item, s.span, ignore_errors)
                     .map(|val| val.into_pipeline_data())
             }
-            PipelineData::Value(v, ..) => match v {
-                Value::String { val: s, span } => {
-                    super::encoding::encode(head, encoding, &s, span, ignore_errors)
-                        .map(|val| val.into_pipeline_data())
+            PipelineData::Value(v, ..) => {
+                let span = v.span();
+                match v {
+                    Value::String { val: s, .. } => {
+                        super::encoding::encode(head, encoding, &s, span, ignore_errors)
+                            .map(|val| val.into_pipeline_data())
+                    }
+                    Value::Error { error, .. } => Err(*error),
+                    _ => Err(ShellError::OnlySupportsThisInputType {
+                        exp_input_type: "string".into(),
+                        wrong_type: v.get_type().to_string(),
+                        dst_span: head,
+                        src_span: v.span(),
+                    }),
                 }
-                Value::Error { error } => Err(*error),
-                _ => Err(ShellError::OnlySupportsThisInputType {
-                    exp_input_type: "string".into(),
-                    wrong_type: v.get_type().to_string(),
-                    dst_span: head,
-                    src_span: v.expect_span(),
-                }),
-            },
+            }
             // This should be more precise, but due to difficulties in getting spans
             // from PipelineData::ListStream, this is as it is.
             _ => Err(ShellError::UnsupportedInput(
