@@ -6,8 +6,8 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, ListStream, PipelineData, ShellError, Signature, Span, Spanned, SyntaxShape,
-    Type, Value,
+    Category, Example, ListStream, PipelineData, Record, ShellError, Signature, Span, Spanned,
+    SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -43,14 +43,13 @@ impl Command for Parse {
     }
 
     fn examples(&self) -> Vec<Example> {
-        let result = Value::List {
-            vals: vec![Value::Record {
+        let result = Value::list(
+            vec![Value::test_record(Record {
                 cols: vec!["foo".to_string(), "bar".to_string()],
                 vals: vec![Value::test_string("hi"), Value::test_string("there")],
-                span: Span::test_data(),
-            }],
-            span: Span::test_data(),
-        };
+            })],
+            Span::test_data(),
+        );
 
         vec![
             Example {
@@ -66,61 +65,56 @@ impl Command for Parse {
             Example {
                 description: "Parse a string using fancy-regex named capture group pattern",
                 example: "\"foo bar.\" | parse -r '\\s*(?<name>\\w+)(?=\\.)'",
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
                         cols: vec!["name".to_string()],
                         vals: vec![Value::test_string("bar")],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Parse a string using fancy-regex capture group pattern",
                 example: "\"foo! bar.\" | parse -r '(\\w+)(?=\\.)|(\\w+)(?=!)'",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec!["capture0".to_string(), "capture1".to_string()],
                             vals: vec![Value::test_string(""), Value::test_string("foo")],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec!["capture0".to_string(), "capture1".to_string()],
                             vals: vec![Value::test_string("bar"), Value::test_string("")],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Parse a string using fancy-regex look behind pattern",
                 example:
                     "\" @another(foo bar)   \" | parse -r '\\s*(?<=[() ])(@\\w+)(\\([^)]*\\))?\\s*'",
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
                         cols: vec!["capture0".to_string(), "capture1".to_string()],
                         vals: vec![
                             Value::test_string("@another"),
                             Value::test_string("(foo bar)"),
                         ],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Parse a string using fancy-regex look ahead atomic group pattern",
                 example: "\"abcd\" | parse -r '^a(bc(?=d)|b)cd$'",
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
                         cols: vec!["capture0".to_string()],
                         vals: vec![Value::test_string("b")],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -179,7 +173,6 @@ fn operate(
                         let results = regex_pattern.captures_iter(&s);
 
                         for c in results {
-                            let mut cols = Vec::with_capacity(columns.len());
                             let captures = match c {
                                 Ok(c) => c,
                                 Err(e) => {
@@ -192,29 +185,25 @@ fn operate(
                                     ))
                                 }
                             };
-                            let mut vals = Vec::with_capacity(captures.len());
 
-                            for (column_name, cap) in columns.iter().zip(captures.iter().skip(1)) {
-                                let cap_string = cap.map(|v| v.as_str()).unwrap_or("").to_string();
-                                cols.push(column_name.clone());
-                                vals.push(Value::String {
-                                    val: cap_string,
-                                    span: v.span()?,
-                                });
-                            }
+                            let v_span = v.span();
+                            let record = columns
+                                .iter()
+                                .zip(captures.iter().skip(1))
+                                .map(|(column_name, cap)| {
+                                    let cap_string = cap.map(|v| v.as_str()).unwrap_or("");
+                                    (column_name.clone(), Value::string(cap_string, v_span))
+                                })
+                                .collect();
 
-                            parsed.push(Value::Record {
-                                cols,
-                                vals,
-                                span: head,
-                            });
+                            parsed.push(Value::record(record, head));
                         }
                     }
                     Err(_) => {
                         return Err(ShellError::PipelineMismatch {
                             exp_input_type: "string".into(),
                             dst_span: head,
-                            src_span: v.span()?,
+                            src_span: v.span(),
                         })
                     }
                 }
@@ -350,21 +339,24 @@ impl Iterator for ParseStreamer {
                 }
             }
 
-            let Some(v) = self.stream.next() else { return None };
+            let Some(v) = self.stream.next() else {
+                return None;
+            };
 
             let Ok(s) = v.as_string() else {
-                return Some(Value::Error {
-                    error: Box::new(ShellError::PipelineMismatch {
+                return Some(Value::error(
+                    ShellError::PipelineMismatch {
                         exp_input_type: "string".into(),
                         dst_span: self.span,
-                        src_span: v.span().unwrap_or(self.span),
-                    }),
-                })
+                        src_span: v.span(),
+                    },
+                    v.span(),
+                ));
             };
 
             let parsed = stream_helper(
                 self.regex.clone(),
-                v.span().unwrap_or(self.span),
+                v.span(),
                 s,
                 self.columns.clone(),
                 &mut self.excess,
@@ -411,22 +403,19 @@ impl Iterator for ParseStreamerExternal {
 
         let chunk = match chunk {
             Some(Ok(chunk)) => chunk,
-            Some(Err(err)) => {
-                return Some(Value::Error {
-                    error: Box::new(err),
-                })
-            }
+            Some(Err(err)) => return Some(Value::error(err, self.span)),
             _ => return None,
         };
 
         let Ok(chunk) = String::from_utf8(chunk) else {
-            return Some(Value::Error {
-                error: Box::new(ShellError::PipelineMismatch {
+            return Some(Value::error(
+                ShellError::PipelineMismatch {
                     exp_input_type: "string".into(),
                     dst_span: self.span,
                     src_span: self.span,
-                }),
-            })
+                },
+                self.span,
+            ));
         };
 
         stream_helper(
@@ -449,33 +438,32 @@ fn stream_helper(
     let results = regex.captures_iter(&s);
 
     for c in results {
-        let mut cols = Vec::with_capacity(columns.len());
         let captures = match c {
             Ok(c) => c,
             Err(e) => {
-                return Some(Value::Error {
-                    error: Box::new(ShellError::GenericError(
+                return Some(Value::error(
+                    ShellError::GenericError(
                         "Error with regular expression captures".into(),
                         e.to_string(),
-                        None,
-                        None,
+                        Some(span),
+                        Some(e.to_string()),
                         Vec::new(),
-                    )),
-                })
+                    ),
+                    span,
+                ))
             }
         };
-        let mut vals = Vec::with_capacity(captures.len());
 
-        for (column_name, cap) in columns.iter().zip(captures.iter().skip(1)) {
-            let cap_string = cap.map(|v| v.as_str()).unwrap_or("").to_string();
-            cols.push(column_name.clone());
-            vals.push(Value::String {
-                val: cap_string,
-                span,
-            });
-        }
+        let record = columns
+            .iter()
+            .zip(captures.iter().skip(1))
+            .map(|(column_name, cap)| {
+                let cap_string = cap.map(|v| v.as_str()).unwrap_or("");
+                (column_name.clone(), Value::string(cap_string, span))
+            })
+            .collect();
 
-        excess.push(Value::Record { cols, vals, span });
+        excess.push(Value::record(record, span));
     }
 
     if !excess.is_empty() {
