@@ -3,7 +3,7 @@ use nu_engine::CallExt;
 use nu_protocol::{
     ast::{Call, CellPath},
     engine::{Command, EngineState, Stack},
-    levenshtein_distance, Category, Example, PipelineData, ShellError, Signature, Span,
+    levenshtein_distance, Category, Example, PipelineData, Record, ShellError, Signature, Span,
     SyntaxShape, Type, Value,
 };
 
@@ -80,26 +80,24 @@ impl Command for SubCommand {
         Example {
             description: "Compute edit distance between strings in table and another string, using cell paths",
             example: "[{a: 'nutshell' b: 'numetal'}] | str distance 'nushell' 'a' 'b'",
-            result: Some(Value::List {
-                vals: vec![
-                    Value::Record {
+            result: Some(Value::list (
+                vec![
+                    Value::test_record(Record {
                         cols: vec!["a".to_string(), "b".to_string()],
                         vals: vec![Value::test_int(1), Value::test_int(4)],
-                        span: Span::test_data(),
-                    }
+                    })
                 ],
-                span: Span::test_data(),
-            }),
+                 Span::test_data(),
+            )),
         },
         Example {
             description: "Compute edit distance between strings in record and another string, using cell paths",
             example: "{a: 'nutshell' b: 'numetal'} | str distance 'nushell' a b",
             result: Some(
-                    Value::Record {
+                    Value::test_record(Record {
                         cols: vec!["a".to_string(), "b".to_string()],
                         vals: vec![Value::test_int(1), Value::test_int(4)],
-                        span: Span::test_data(),
-                    }
+                    })
                 ),
         }]
     }
@@ -113,14 +111,15 @@ fn action(input: &Value, args: &Arguments, head: Span) -> Value {
             Value::int(distance as i64, head)
         }
         Value::Error { .. } => input.clone(),
-        _ => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        _ => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "string".into(),
                 wrong_type: input.get_type().to_string(),
                 dst_span: head,
-                src_span: input.expect_span(),
-            }),
-        },
+                src_span: input.span(),
+            },
+            head,
+        ),
     }
 }
 
