@@ -115,7 +115,7 @@ impl Command for SubCommand {
             },
             Example {
                 description: "Find and replace all occurrences of a substring",
-                example: r#"'abc abc abc' | str replace -a 'b' 'z'"#,
+                example: r#"'abc abc abc' | str replace --all 'b' 'z'"#,
                 result: Some(Value::test_string("azc azc azc")),
             },
             Example {
@@ -125,13 +125,13 @@ impl Command for SubCommand {
             },
             Example {
                 description: "Find and replace all occurrences of find string using regular expression",
-                example: "'abc abc abc' | str replace -ar 'b' 'z'",
+                example: "'abc abc abc' | str replace --all --regex 'b' 'z'",
                 result: Some(Value::test_string("azc azc azc")),
             },
             Example {
                 description: "Find and replace all occurrences of find string in table using regular expression",
                 example:
-                    "[[ColA ColB ColC]; [abc abc ads]] | str replace -ar 'b' 'z' ColA ColC",
+                    "[[ColA ColB ColC]; [abc abc ads]] | str replace --all --regex 'b' 'z' ColA ColC",
                 result: Some(Value::list (
                     vec![Value::test_record(Record {
                         cols: vec!["ColA".to_string(), "ColB".to_string(), "ColC".to_string()],
@@ -147,7 +147,7 @@ impl Command for SubCommand {
             Example {
                 description: "Find and replace all occurrences of find string in record using regular expression",
                 example:
-                    "{ KeyA: abc, KeyB: abc, KeyC: ads } | str replace -ar 'b' 'z' KeyA KeyC",
+                    "{ KeyA: abc, KeyB: abc, KeyC: ads } | str replace --all --regex 'b' 'z' KeyA KeyC",
                 result: Some(Value::test_record(Record {
                         cols: vec!["KeyA".to_string(), "KeyB".to_string(), "KeyC".to_string()],
                         vals: vec![
@@ -179,7 +179,7 @@ impl Command for SubCommand {
             },
             Example {
                 description: "Find and replace on individual lines using multiline regular expression",
-                example: r#""non-matching line\n123. one line\n124. another line\n" | str replace -am '^[0-9]+\. ' ''"#,
+                example: r#""non-matching line\n123. one line\n124. another line\n" | str replace --all --multiline '^[0-9]+\. ' ''"#,
                 result: Some(Value::test_string("non-matching line\none line\nanother line\n")),
             },
 
