@@ -44,12 +44,9 @@ fn row() {
 #[test]
 fn single_record_no_overwrite() {
     assert_eq!(
-        nu!(
-            cwd: ".", pipeline(
-            r#"
+        nu!("
             {a: 1, b: 5} | merge {c: 2} | to nuon
-            "#
-        ))
+            ")
         .out,
         "{a: 1, b: 5, c: 2}"
     );
@@ -58,12 +55,9 @@ fn single_record_no_overwrite() {
 #[test]
 fn single_record_overwrite() {
     assert_eq!(
-        nu!(
-            cwd: ".", pipeline(
-            r#"
+        nu!("
             {a: 1, b: 2} | merge {a: 2} | to nuon
-            "#
-        ))
+            ")
         .out,
         "{a: 2, b: 2}"
     );
@@ -72,12 +66,9 @@ fn single_record_overwrite() {
 #[test]
 fn single_row_table_overwrite() {
     assert_eq!(
-        nu!(
-            cwd: ".", pipeline(
-            r#"
+        nu!("
             [[a b]; [1 4]] | merge [[a b]; [2 4]] | to nuon
-            "#
-        ))
+            ")
         .out,
         "[[a, b]; [2, 4]]"
     );
@@ -86,12 +77,9 @@ fn single_row_table_overwrite() {
 #[test]
 fn single_row_table_no_overwrite() {
     assert_eq!(
-        nu!(
-            cwd: ".", pipeline(
-            r#"
+        nu!("
             [[a b]; [1 4]] | merge [[c d]; [2 4]] | to nuon
-            "#
-        ))
+            ")
         .out,
         "[[a, b, c, d]; [1, 4, 2, 4]]"
     );
@@ -100,12 +88,9 @@ fn single_row_table_no_overwrite() {
 #[test]
 fn multi_row_table_no_overwrite() {
     assert_eq!(
-        nu!(
-            cwd: ".", pipeline(
-            r#"
+        nu!("
             [[a b]; [1 4] [8 9] [9 9]] | merge [[c d]; [2 4]]  | to nuon
-            "#
-        ))
+            ")
         .out,
         "[{a: 1, b: 4, c: 2, d: 4}, {a: 8, b: 9}, {a: 9, b: 9}]"
     );
@@ -114,12 +99,9 @@ fn multi_row_table_no_overwrite() {
 #[test]
 fn multi_row_table_overwrite() {
     assert_eq!(
-        nu!(
-            cwd: ".", pipeline(
-            r#"
+        nu!("
             [[a b]; [1 4] [8 9] [9 9]] | merge  [[a b]; [7 7]]  | to nuon
-            "#
-        ))
+            ")
         .out,
         "[[a, b]; [7, 7], [8, 9], [9, 9]]"
     );
