@@ -7,6 +7,8 @@ mod break_;
 mod cal;
 mod cd;
 mod compact;
+mod config_env_default;
+mod config_nu_default;
 mod continue_;
 mod conversions;
 mod cp;
@@ -101,6 +103,7 @@ mod touch;
 mod transpose;
 mod try_;
 mod ucp;
+mod unfold;
 mod uniq;
 mod uniq_by;
 mod update;
