@@ -94,3 +94,21 @@ fn http_post_json_is_success() {
     mock.assert();
     assert!(actual.out.is_empty())
 }
+
+#[test]
+fn http_post_json_list_is_success() {
+    let mut server = Server::new();
+
+    let mock = server
+        .mock("POST", "/")
+        .match_body(r#"[{"foo":"bar"}]"#)
+        .create();
+
+    let actual = nu!(format!(
+        r#"http post -t 'application/json' {url} [{{foo: "bar"}}]"#,
+        url = server.url()
+    ));
+
+    mock.assert();
+    assert!(actual.out.is_empty())
+}
