@@ -33,7 +33,7 @@ fn copies_a_file_impl(progress: bool) {
 
         nu!(
             cwd: dirs.root(),
-            "ucp {} `{}` ucp_test_1/sample.ini",
+            "cp {} `{}` ucp_test_1/sample.ini",
             progress_flag,
             test_file.display()
         );
@@ -61,7 +61,7 @@ fn copies_the_file_inside_directory_if_path_to_copy_is_directory_impl(progress:
         let first_hash = get_file_hash(dirs.formats().join("../formats/sample.ini").display());
         nu!(
             cwd: dirs.formats(),
-            "ucp {} ../formats/sample.ini {}",
+            "cp {} ../formats/sample.ini {}",
             progress_flag,
             expected_file.dir()
         );
@@ -86,20 +86,13 @@ fn error_if_attempting_to_copy_a_directory_to_another_directory_impl(progress: b
         let progress_flag = if progress { "-p" } else { "" };
         let actual = nu!(
             cwd: dirs.formats(),
-            "ucp {} ../formats {}",
+            "cp {} ../formats {}",
             progress_flag,
             dirs.test().display()
         );
 
-        // Changing to GNU error like error
-        // Slight bug since it should say formats, but its saying "." due to the `strip_prefix`
-        // that i do I think
-        // assert!(actual.err.contains("formats"));
-        // assert!(actual.err.contains("resolves to a directory (not copied)"));
-        assert!(actual.err.contains("omitting directory"));
-
-        // directories must be copied using --recursive
-        // gnu says "omitting directory", vbecause -r was not given
+        assert!(actual.err.contains("formats"));
+        assert!(actual.err.contains("resolves to a directory (not copied)"));
     });
 }
 
@@ -131,7 +124,7 @@ fn copies_the_directory_inside_directory_if_path_to_copy_is_directory_and_with_r
 
         nu!(
             cwd: dirs.test(),
-            "ucp {} originals expected -r",
+            "cp {} originals expected -r",
             progress_flag
         );
 
@@ -181,7 +174,7 @@ fn deep_copies_with_recursive_flag_impl(progress: bool) {
 
         nu!(
             cwd: dirs.test(),
-            "ucp {} originals expected --recursive",
+            "cp {} originals expected --recursive",
             progress_flag
         );
 
@@ -220,7 +213,7 @@ fn copies_using_path_with_wildcard_impl(progress: bool) {
 
         nu!(
             cwd: dirs.formats(),
-            "ucp {} -r ../formats/* {}",
+            "cp {} -r ../formats/* {}",
             progress_flag,
             dirs.test().display()
         );
@@ -265,7 +258,7 @@ fn copies_using_a_glob_impl(progress: bool) {
 
         nu!(
             cwd: dirs.formats(),
-            "ucp {} -r * {}",
+            "cp {} -r * {}",
             progress_flag,
             dirs.test().display()
         );
@@ -305,14 +298,14 @@ fn copies_same_file_twice_impl(progress: bool) {
 
         nu!(
             cwd: dirs.root(),
-            "ucp {} `{}` ucp_test_8/sample.ini",
+            "cp {} `{}` ucp_test_8/sample.ini",
             progress_flag,
             dirs.formats().join("sample.ini").display()
         );
 
         nu!(
             cwd: dirs.root(),
-            "ucp {} `{}` ucp_test_8/sample.ini",
+            "cp {} `{}` ucp_test_8/sample.ini",
             progress_flag,
             dirs.formats().join("sample.ini").display()
         );
@@ -377,7 +370,7 @@ fn copy_file_and_dir_from_two_parents_up_using_multiple_dots_to_current_dir_recu
 
         nu!(
             cwd: dirs.test().join("foo/bar"),
-            "ucp {} -r .../hello* .",
+            "cp {} -r .../hello* .",
             progress_flag
         );
 
@@ -401,7 +394,7 @@ fn copy_to_non_existing_dir_impl(progress: bool) {
 
         let actual = nu!(
             cwd: sandbox.cwd(),
-            "ucp {} empty_file ~/not_a_dir{}",
+            "cp {} empty_file ~/not_a_dir{}",
             progress_flag,
             PATH_SEPARATOR,
         );
@@ -519,7 +512,7 @@ fn copy_identical_file_impl(progress: bool) {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "ucp {} same.txt same.txt",
+            "cp {} same.txt same.txt",
             progress_flag,
         );
         // assert!(actual.err.contains("Copy aborted"));
@@ -575,7 +568,7 @@ fn copy_file_not_exists_dst_impl(progress: bool) {
 
         let actual = nu!(
             cwd: sandbox.cwd(),
-            "ucp {} valid.txt ~/invalid_dir/invalid_dir1",
+            "cp {} valid.txt ~/invalid_dir/invalid_dir1",
             progress_flag,
         );
         assert!(
@@ -604,7 +597,7 @@ fn copy_file_with_read_permission_impl(progress: bool) {
 
         let actual = nu!(
             cwd: sandbox.cwd(),
-            "ucp {} valid.txt invalid_prem.txt",
+            "cp {} valid.txt invalid_prem.txt",
             progress_flag,
         );
         assert!(actual.err.contains("invalid_prem.txt") && actual.err.contains("denied"));
@@ -636,7 +629,7 @@ fn test_cp_cp() {
 
         nu!(
             cwd: dirs.root(),
-            "ucp {} ucp_test_19/{}",
+            "cp {} ucp_test_19/{}",
             src.display(),
             TEST_HELLO_WORLD_DEST
         );
@@ -661,7 +654,7 @@ fn test_cp_existing_target() {
         // Copy existing file to destination, so that it exists for the test
         nu!(
             cwd: dirs.root(),
-            "ucp {} ucp_test_20/{}",
+            "cp {} ucp_test_20/{}",
             existing.display(),
             TEST_EXISTING_FILE
         );
@@ -672,7 +665,7 @@ fn test_cp_existing_target() {
         // Now for the test
         nu!(
             cwd: dirs.root(),
-            "ucp {} ucp_test_20/{}",
+            "cp {} ucp_test_20/{}",
             src.display(),
             TEST_EXISTING_FILE
         );
@@ -701,7 +694,7 @@ fn test_cp_multiple_files() {
         // Start test
         nu!(
             cwd: dirs.root(),
-            "ucp {} {} ucp_test_21/{}",
+            "cp {} {} ucp_test_21/{}",
             src1.display(),
             src2.display(),
             TEST_COPY_TO_FOLDER
@@ -734,7 +727,7 @@ fn test_cp_recurse() {
         // Start test
         nu!(
             cwd: dirs.root(),
-            "ucp -r {} ucp_test_22/{}",
+            "cp -r {} ucp_test_22/{}",
             TEST_COPY_FROM_FOLDER,
             TEST_COPY_TO_FOLDER_NEW,
         );
@@ -754,7 +747,7 @@ fn test_cp_with_dirs() {
         // Start test
         nu!(
             cwd: dirs.root(),
-            "ucp {} ucp_test_23/{}",
+            "cp {} ucp_test_23/{}",
             src.display(),
             TEST_COPY_TO_FOLDER,
         );
@@ -767,7 +760,7 @@ fn test_cp_with_dirs() {
         let src2_hash = get_file_hash(src2.display());
         nu!(
             cwd: dirs.root(),
-            "ucp {} ucp_test_23/{}",
+            "cp {} ucp_test_23/{}",
             src2.display(),
             TEST_HELLO_WORLD_DEST,
         );
@@ -785,7 +778,7 @@ fn test_cp_arg_force() {
 
         nu!(
         cwd: dirs.root(),
-        "ucp {} --force ucp_test_24/{}",
+        "cp {} --force ucp_test_24/{}",
         src.display(),
         "invalid_prem.txt"
         );
@@ -801,7 +794,7 @@ fn test_cp_directory_to_itself_disallowed() {
         sandbox.mkdir("d");
         let actual = nu!(
         cwd: dirs.root(),
-        "ucp -r ucp_test_25/{}  ucp_test_25/{}",
+        "cp -r ucp_test_25/{}  ucp_test_25/{}",
         "d",
         "d"
         );
@@ -819,7 +812,7 @@ fn test_cp_nested_directory_to_itself_disallowed() {
         sandbox.mkdir("a/b/c");
         let actual = nu!(
         cwd: dirs.test(),
-        "ucp -r {} {}",
+        "cp -r {} {}",
         "a/b",
         "a/b/c"
         );
@@ -836,7 +829,7 @@ fn test_cp_same_file_force() {
         sandbox.with_files(vec![EmptyFile("f")]);
         let actual = nu!(
         cwd: dirs.test(),
-        "ucp --force {} {}",
+        "cp --force {} {}",
         "f",
         "f"
         );
@@ -854,7 +847,7 @@ fn test_cp_arg_no_clobber() {
 
         let actual = nu!(
         cwd: dirs.root(),
-        "ucp {} {} --no-clobber",
+        "cp {} {} --no-clobber",
         src.display(),
         target.display()
         );
@@ -874,7 +867,7 @@ fn test_cp_arg_no_clobber_twice() {
         ]);
         nu!(
         cwd: dirs.root(),
-        "ucp --no-clobber ucp_test_29/{} ucp_test_29/{}",
+        "cp --no-clobber ucp_test_29/{} ucp_test_29/{}",
         "source.txt",
         "dest.txt"
         );
@@ -882,7 +875,7 @@ fn test_cp_arg_no_clobber_twice() {
 
         nu!(
         cwd: dirs.root(),
-        "ucp --no-clobber ucp_test_29/{} ucp_test_29/{}",
+        "cp --no-clobber ucp_test_29/{} ucp_test_29/{}",
         "source_with_body.txt",
         "dest.txt"
         );
@@ -898,7 +891,7 @@ fn test_cp_debug_default() {
 
         let actual = nu!(
         cwd: dirs.root(),
-        "ucp --debug {} ucp_test_30/{}",
+        "cp --debug {} ucp_test_30/{}",
         src.display(),
         TEST_HELLO_WORLD_DEST
         );
@@ -933,7 +926,7 @@ fn test_cp_verbose_default() {
 
         let actual = nu!(
         cwd: dirs.root(),
-        "ucp --verbose {} {}",
+        "cp --verbose {} {}",
         src.display(),
         TEST_HELLO_WORLD_DEST
         );
@@ -954,7 +947,7 @@ fn test_cp_only_source_no_dest() {
         let src = dirs.fixtures.join("cp").join(TEST_HELLO_WORLD_SOURCE);
         let actual = nu!(
         cwd: dirs.root(),
-        "ucp {}",
+        "cp {}",
         src.display(),
         );
         assert!(actual
@@ -970,7 +963,7 @@ fn test_cp_with_vars() {
         sandbox.with_files(vec![EmptyFile("input")]);
         nu!(
         cwd: dirs.test(),
-        "let src = 'input'; let dst = 'target'; ucp $src $dst",
+        "let src = 'input'; let dst = 'target'; cp $src $dst",
         );
         assert!(dirs.test().join("target").exists());
     });
