@@ -4,7 +4,6 @@ pub mod documentation;
 pub mod env;
 mod eval;
 mod glob_from;
-mod nu_variable;
 pub mod scope;
 
 pub use call_ext::CallExt;
@@ -13,6 +12,6 @@ pub use documentation::get_full_help;
 pub use env::*;
 pub use eval::{
     eval_block, eval_block_with_early_return, eval_call, eval_expression,
-    eval_expression_with_input, eval_operator, eval_subexpression, eval_variable, redirect_env,
+    eval_expression_with_input, eval_subexpression, eval_variable, redirect_env,
 };
 pub use glob_from::glob_from;
