@@ -75,12 +75,12 @@ impl From<ShellError> for LabeledError {
                 help: _help,
             } => LabeledError {
                 label: format!("Can't convert to {expected}"),
-                msg: format!("can't convert {expected} to {input}"),
+                msg: format!("can't convert from {input} to {expected}"),
                 span: Some(span),
             },
             ShellError::DidYouMean(suggestion, span) => LabeledError {
                 label: "Name not found".into(),
-                msg: format!("did you mean '{suggestion}'"),
+                msg: format!("did you mean '{suggestion}'?"),
                 span: Some(span),
             },
             ShellError::PluginFailedToLoad(msg) => LabeledError {
