@@ -76,6 +76,7 @@ pub struct Config {
     pub table_move_header: bool,
     pub table_show_empty: bool,
     pub table_indent: TableIndent,
+    pub table_abbreviation_threshold: Option<usize>,
     pub use_ls_colors: bool,
     pub color_config: HashMap<String, Value>,
     pub use_grid_icons: bool,
@@ -97,9 +98,8 @@ pub struct Config {
     pub hooks: Hooks,
     pub rm_always_trash: bool,
     pub shell_integration: bool,
-    pub buffer_editor: String,
+    pub buffer_editor: Value,
     pub table_index_mode: TableIndexMode,
-    pub cd_with_abbreviations: bool,
     pub case_sensitive_completions: bool,
     pub enable_external_completion: bool,
     pub trim_strategy: TrimStrategy,
@@ -114,6 +114,7 @@ pub struct Config {
     pub datetime_normal_format: Option<String>,
     pub datetime_table_format: Option<String>,
     pub error_style: String,
+    pub use_kitty_protocol: bool,
 }
 
 impl Default for Config {
@@ -126,14 +127,13 @@ impl Default for Config {
 
             rm_always_trash: false,
 
-            cd_with_abbreviations: false,
-
             table_mode: "rounded".into(),
             table_index_mode: TableIndexMode::Always,
             table_show_empty: true,
             trim_strategy: TRIM_STRATEGY_DEFAULT,
             table_move_header: false,
             table_indent: TableIndent { left: 1, right: 1 },
+            table_abbreviation_threshold: None,
 
             datetime_normal_format: None,
             datetime_table_format: None,
@@ -164,7 +164,7 @@ impl Default for Config {
             use_grid_icons: true,
             footer_mode: FooterMode::RowCount(25),
             float_precision: 2,
-            buffer_editor: String::new(),
+            buffer_editor: Value::nothing(Span::unknown()),
             use_ansi_coloring: true,
             bracketed_paste: true,
             edit_mode: "emacs".into(),
@@ -178,6 +178,8 @@ impl Default for Config {
             keybindings: Vec::new(),
 
             error_style: "fancy".into(),
+
+            use_kitty_protocol: false,
         }
     }
 }
@@ -382,19 +384,14 @@ impl Value {
                             for index in (0..cols.len()).rev() {
                                 let value = &vals[index];
                                 let key2 = cols[index].as_str();
-                                match key2 {
-                                    "abbreviations" => {
-                                        try_bool!(cols, vals, index, span, cd_with_abbreviations)
-                                    }
-                                    x => {
-                                        invalid_key!(
-                                            cols,
-                                            vals,
-                                            index,
-                                            Some(value.span()),
-                                            "$env.config.{key}.{x} is an unknown config setting"
-                                        );
-                                    }
+                                {
+                                    invalid_key!(
+                                        cols,
+                                        vals,
+                                        index,
+                                        Some(value.span()),
+                                        "$env.config.{key}.{key2} is an unknown config setting"
+                                    );
                                 }
                             }
                         } else {
@@ -1023,6 +1020,17 @@ impl Value {
                                     "show_empty" => {
                                         try_bool!(cols, vals, index, span, table_show_empty)
                                     }
+                                    "abbreviated_row_count" => {
+                                        if let Ok(b) = value.as_int() {
+                                            if b < 0 {
+                                                invalid!(Some(span), "should be an int unsigned");
+                                            }
+
+                                            config.table_abbreviation_threshold = Some(b as usize);
+                                        } else {
+                                            invalid!(Some(span), "should be an int");
+                                        }
+                                    }
                                     x => {
                                         invalid_key!(
                                             cols,
@@ -1171,13 +1179,20 @@ impl Value {
                     "shell_integration" => {
                         try_bool!(cols, vals, index, span, shell_integration);
                     }
-                    "buffer_editor" => {
-                        if let Ok(v) = value.as_string() {
-                            config.buffer_editor = v.to_lowercase();
-                        } else {
-                            invalid!(Some(span), "should be a string");
+                    "buffer_editor" => match value {
+                        Value::Nothing { .. } | Value::String { .. } => {
+                            config.buffer_editor = value.clone();
                         }
-                    }
+                        Value::List { vals, .. }
+                            if vals.iter().all(|val| matches!(val, Value::String { .. })) =>
+                        {
+                            config.buffer_editor = value.clone();
+                        }
+                        _ => {
+                            dbg!(value);
+                            invalid!(Some(span), "should be a string, list<string>, or null");
+                        }
+                    },
                     "show_banner" => {
                         try_bool!(cols, vals, index, span, show_banner);
                     }
@@ -1187,6 +1202,9 @@ impl Value {
                     "bracketed_paste" => {
                         try_bool!(cols, vals, index, span, bracketed_paste);
                     }
+                    "use_kitty_protocol" => {
+                        try_bool!(cols, vals, index, span, use_kitty_protocol);
+                    }
                     // Menus
                     "menus" => match create_menus(value) {
                         Ok(map) => config.menus = map,
