@@ -27,6 +27,8 @@ pub fn load_standard_library(
             ("assert.nu", include_str!("../std/assert.nu")),
             ("xml.nu", include_str!("../std/xml.nu")),
             ("input.nu", include_str!("../std/input.nu")),
+            ("math.nu", include_str!("../std/math.nu")),
+            ("formats.nu", include_str!("../std/formats.nu")),
         ];
 
         let mut working_set = StateWorkingSet::new(engine_state);
