@@ -1,4 +1,4 @@
-use nu_command::hook::{eval_env_change_hook, eval_hook};
+use nu_cmd_base::hook::{eval_env_change_hook, eval_hook};
 use nu_engine::eval_block;
 use nu_parser::parse;
 use nu_protocol::engine::{EngineState, Stack, StateWorkingSet};
@@ -213,7 +213,14 @@ pub fn nu_repl() {
         // Check for pre_prompt hook
         let config = engine_state.get_config();
         if let Some(hook) = config.hooks.pre_prompt.clone() {
-            if let Err(err) = eval_hook(&mut engine_state, &mut stack, None, vec![], &hook) {
+            if let Err(err) = eval_hook(
+                &mut engine_state,
+                &mut stack,
+                None,
+                vec![],
+                &hook,
+                "pre_prompt",
+            ) {
                 outcome_err(&engine_state, &err);
             }
         }
@@ -238,7 +245,14 @@ pub fn nu_repl() {
             .buffer = line.to_string();
 
         if let Some(hook) = config.hooks.pre_execution.clone() {
-            if let Err(err) = eval_hook(&mut engine_state, &mut stack, None, vec![], &hook) {
+            if let Err(err) = eval_hook(
+                &mut engine_state,
+                &mut stack,
+                None,
+                vec![],
+                &hook,
+                "pre_execution",
+            ) {
                 outcome_err(&engine_state, &err);
             }
         }
