@@ -116,6 +116,7 @@ pub fn run_test_contains(input: &str, expected: &str) -> TestResult {
     println!("stdout: {stdout}");
     println!("stderr: {stderr}");
 
+    println!("Expected output to contain: {expected}");
     assert!(output.status.success());
 
     assert!(stdout.contains(expected));
@@ -144,6 +145,7 @@ pub fn test_ide_contains(input: &str, ide_commands: &[&str], expected: &str) ->
 
     println!("stdout: {stdout}");
     println!("stderr: {stderr}");
+    println!("Expected output to contain: {expected}");
 
     assert!(output.status.success());
 
@@ -174,6 +176,7 @@ pub fn fail_test(input: &str, expected: &str) -> TestResult {
 
     println!("stdout: {stdout}");
     println!("stderr: {stderr}");
+    println!("Expected error to contain: {expected}");
 
     assert!(!stderr.is_empty() && stderr.contains(expected));
 
