@@ -129,15 +129,6 @@ fn command_not_found_error_shows_not_found_1() {
     assert!(actual.err.contains("'foo' was not found"));
 }
 
-#[test]
-fn command_not_found_error_shows_not_found_2() {
-    let actual = nu!(r#"
-            export extern-wrapped my-foo [...rest] { foo };
-            my-foo
-        "#);
-    assert!(actual.err.contains("did you mean"));
-}
-
 #[test]
 fn command_substitution_wont_output_extra_newline() {
     let actual = nu!(r#"
